@@ -1,7 +1,9 @@
+from typing import Union, Optional
 from abc import ABC
-from typing import Union
+import logging
 
-from mpris_server.adapters import EventAdapter, MprisAdapter
+from mpris_server.adapters import MprisAdapter
+from mpris_server.events import EventAdapter
 from mpris_server.server import Server
 
 from pychromecast.controllers.media import MediaStatus
@@ -10,14 +12,22 @@ from pychromecast import Chromecast
 
 from .base import Status
 
+
+DEBUG_FN = 'chromecast_mpris.txt'
+
+#logging.basicConfig(filename=DEBUG_FN)
+
+
 class ChromecastEventListener(ABC):
   """
   Event listeners that conform to pychromecast's API
   """
   def new_media_status(self, status: MediaStatus):
+    # logging.info(repr(status))
     pass
 
   def new_cast_status(self, status: CastStatus):
+    # logging.info(repr(status))
     pass
 
 
@@ -46,11 +56,13 @@ class ChromecastEventHandler(ChromecastEventAdapter,
       self.on_volume()
 
   def new_media_status(self, status: MediaStatus):
+    super().new_media_status(status)
     self.check_volume(status)
     self.on_playback()
     self.on_options()
 
   def new_cast_status(self, status: CastStatus):
+    super().new_cast_status(status)
     self.check_volume(status)
 
 
